//
//  View.swift
//  Navigate
//
//  Created by Mark Meretzky on 12/3/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit

class StationView: UIView {
	let stationController: StationController;

	init(stationController: StationController) {
		self.stationController = stationController;
		super.init(frame: CGRectZero);
		backgroundColor = UIColor.yellowColor();
		//Call drawRect whenever orientation changes.
		contentMode = UIViewContentMode.Redraw;
	}

	//not called
	required init(coder aDecoder: NSCoder) {
		stationController = StationController(title: "");
		super.init(coder: aDecoder);
	}
	
	override func touchesEnded(touches: NSSet, withEvent event: UIEvent) {
		let lineController: LineController = stationController.navigationController! as LineController;
		lineController.next();	//Advance east to the next station.
	}

	//Put the origin (0, 0) of this View at the lower left corner of the navigation bar.
	//When drawRect prints at the origin, it will therefore print at the lower left
	//corner of the navigation bar.

	override func layoutSubviews() {
		bounds.origin = CGPointMake(
			bounds.origin.x,
			-stationController.topLayoutGuide.length);
	}

	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.

	override func drawRect(rect: CGRect) {
		// Drawing code
		let lineController: LineController = stationController.navigationController! as LineController;
		let i: Int = lineController.viewControllers.count;
		let n: Int = lineController.titles.count;

		var s: String = "\(stationController.title!)\n"
			+ "station \(i) of \(n)\n"
			+ "frame = \(frame)\n"
			+ "bounds = \(bounds)\n"
			+ "navigationBar = \(lineController.navigationBar.frame)";

		if i < n {
			//There is a next station.
			s += "\nnext station: \(lineController.titles[i])";
		}

		let m: CGFloat = min(bounds.size.width, bounds.size.height);
		let font: UIFont = UIFont.systemFontOfSize(m / 16);
		let attributes: [NSObject: AnyObject] = [NSFontAttributeName: font];
		s.drawAtPoint(CGPointZero, withAttributes: attributes);
	}

}
